Processor.App.Downloader.dummy\_downloader
==========================================

.. automodule:: Processor.App.Downloader.dummy_downloader

   
   
   

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :toctree:
   
      DownloaderDummy
   
   

   
   
   



